@@ -13,7 +13,7 @@ from func_timeout import func_timeout, FunctionTimedOut
 
 class MapfwBenchmarker:
     def __init__(self, token: str, problem_id: Union[int, iter], algorithm: str, version: str, debug=True,
-                 solver: Callable[[Problem], List] = None):
+                 solver: Callable[[Problem], List] = None, cores=1):
         """
         Helper function to handle API requests
 
@@ -34,6 +34,7 @@ class MapfwBenchmarker:
         self.attempt_id = None
         self.timeout = None
         self.debug = debug
+        self.cores = cores
 
     def __iter__(self):
         warnings.warn("Consult the README for the new way of running benchmarks", DeprecationWarning, stacklevel=2)
@@ -78,8 +79,12 @@ class MapfwBenchmarker:
                         return self.solver(problem)
                 time_func = lambda problem: time_fun(problem, solve_func)
 
-                with Pool() as p:
-                    solutions = list(tqdm(p.imap(time_func, self.problems), total=len(self.problems)))
+                if self.cores == -1:
+                    with Pool() as p:
+                        solutions = list(tqdm(p.imap(time_func, self.problems), total=len(self.problems)))
+                else:
+                    with Pool(self.cores) as p:
+                        solutions = list(tqdm(p.imap(time_func, self.problems), total=len(self.problems)))
 
                 for p in range(len(self.problems)):
                     self.problems[p].add_solution(*solutions[p])
